Improve this Doc

# $sce

Here are the list of errors in the $sce namespace.

Name | Description
--- | ---
icontext | Invalid / Unknown SCE context
iequirks | IE<11 in quirks mode is unsupported
imatcher | Invalid matcher (only string patterns and RegExp instances are supported)
insecurl | Processing of a Resource from Untrusted Source Blocked
itype | String Value is Required for SCE Trust Call
iwcard | The sequence *** is not a valid pattern wildcard
unsafe | Require a safe/trusted value